@@ -1,14 +1,11 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: conversions.c 500 2004-12-08 14:02:44Z kiza $
+ * $Id: conversions.c 1173 2006-10-14 21:41:42Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de> and
  *                     Rene Puls <rpuls@gmx.net>
  *
  * conversions.c
  *
- * Please read the file README.patching before changing any code in this file!
- *
- *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
  * published by the Free Software Foundation.
@@ -34,6 +31,8 @@
 #include <libxml/HTMLparser.h>
 #include <langinfo.h>
 
+#include "os-support.h"
+
 /* I have no idea what needs to be defined to get strptime() on glibc.
  * This is stolen from somewhere else and it works for me(tm).
  * If you know how it's supposed to work, tell me. Manpage says
@@ -103,17 +102,19 @@ char * iconvert (char * inbuf) {
  * instead means "..." (3 dots, "and so on...").
  */
 char * UIDejunk (char * feed_description) {
-	char *start;				/* Points to first char everytime. Need to free this. */
-	char *text;					/* = feed_description.
-	                               Well, at least at the beginning of the func. */
-	char *newtext;				/* Detag'ed *text. */
-	char *detagged;				/* Returned value from strsep. This is what we want. */
-	char *entity;				/* Which HTML crap did we hit now? */
+	char *start;		/* Points to first char everytime. Need to free this. */
+	char *text;			/* feed_description copy */
+	char *newtext;		/* Detag'ed *text. */
+	char *detagged;		/* Returned value from strsep. This is what we want. */
+	char *htmltag;
+/*	char *attribute;*/
+	char *entity;
 	struct entity *cur_entity;
-	int found = 0;				/* User defined entity matched? */
+	int found = 0;		/* User defined entity matched? */
+/*	int len;*/
 #ifdef __STDC_ISO_10646__
+	int len;
 	wchar_t ch;					/* Decoded numeric entity */
-	int len;					/* Current length of detag'd text */
 	int mblen;					/* Length of multi-byte entity */
 #else
 	unsigned long ch;			/* Decoded numeric entity */
@@ -131,7 +132,7 @@ char * UIDejunk (char * feed_description) {
 	start = text;
 	
 	
-	/* If *text begins with a tag, discard all of them. */
+	/* If text begins with a tag, discard all of them. */
 	while (1) {
 		if (text[0] == '<') {
 			strsep (&text, "<");
@@ -174,8 +175,30 @@ char * UIDejunk (char * feed_description) {
 		strcat (newtext, detagged);
 		
 		/* Advance *text to next position after the closed tag. */
-		if ((strsep (&text, ">")) == NULL)
+		htmltag = strsep (&text, ">");
+		if (htmltag == NULL)
 			break;
+		
+		if (s_strcasestr(htmltag, "img src") != NULL) {
+/*			attribute = s_strcasestr(htmltag, "alt=");
+			if (attribute == NULL)
+				continue;
+			len = strlen(attribute);
+			newtext = realloc(newtext, strlen(newtext)+6+len+2);
+			strcat(newtext, "[img: ");
+			strncat(newtext, attribute+5, len-6);
+			strcat(newtext, "]");*/
+
+			newtext = realloc(newtext, strlen(newtext)+7);
+			strcat(newtext, "[img] ");
+		}
+/*		else if (s_strcasestr(htmltag, "a href") != NULL) {
+			newtext = realloc(newtext, strlen(newtext)+8);
+			strcat(newtext, "[link: ");
+		} else if (strcasecmp(htmltag, "/a") == 0) {
+			newtext = realloc(newtext, strlen(newtext)+2);
+			strcat(newtext, "]");
+		}*/
 	}
 	free (start);
 	
@@ -254,7 +277,7 @@ char * UIDejunk (char * feed_description) {
 						else
 							ch = atol(entity + 1);
 					}
-					else if ((ep = htmlEntityLookup(entity)) != NULL)
+					else if ((ep = htmlEntityLookup((xmlChar *)entity)) != NULL)
 						ch = ep->value;
 					else
 						ch = 0;  /* Didn't recognize it. */
@@ -412,7 +435,7 @@ char * WrapText (char * text, int width) {
 }
 
 char *base64encode(char const *inbuf, unsigned int inbuf_size) {
-	static unsigned char const alphabet[64] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
+	static unsigned char const alphabet[65] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 
 	char *outbuf = NULL;
 	unsigned int inbuf_pos = 0;
@@ -467,8 +490,10 @@ char *base64encode(char const *inbuf, unsigned int inbuf_size) {
 	return outbuf;
 }
 
+#ifdef USE_UNSUPPORTED_AND_BROKEN_CODE
 /* Returns NULL on invalid input */
 char* decodechunked(char * chunked, unsigned int *inputlen) {
+#warning ===The function decodedechunked() is not safe for binary data. Since you specifically requested it to be compiled in you probably know better what you are doing than me. Do not report bugs for this code.===
 	char *orig = chunked, *dest = chunked;
 	unsigned long chunklen;
 
@@ -494,6 +519,7 @@ char* decodechunked(char * chunked, unsigned int *inputlen) {
 	
 	return chunked;
 }
+#endif
 
 /* Remove leading whitspaces, newlines, tabs.
  * This function should be safe for working on UTF-8 strings.
@@ -583,7 +609,7 @@ char * genItemHash (char ** hashitems, int items) {
 	
 	for (i = 0; i < items; i++) {
 		if (hashitems[i] != NULL)
-			MD5Update (&MD5Ctx, hashitems[i], strlen(hashitems[i]));
+			MD5Update (&MD5Ctx, (unsigned char *)hashitems[i], strlen(hashitems[i]));
 	}
 	MD5Final (MD5Digest, &MD5Ctx);
 	CvtHex (MD5Digest, HexDigest);
@@ -642,6 +668,7 @@ int pubDateToUnix (char const * const pubDate) {
 	t = malloc(sizeof(struct tm));
 	gmtime_r(&tt, t);
 	
+#ifdef LOCALEPATH
 	/* Cruft!
 	 * Save old locale so we can parse the stupid pubDate format.
 	 * However strftime is not really more intelligent since there is no
@@ -657,6 +684,7 @@ int pubDateToUnix (char const * const pubDate) {
 		 */
 		setlocale(LC_TIME, "C");
 	}
+#endif
 	
 	if (strptime(start_here, "%d %b %Y %T", t)) {
 #ifdef __CYGWIN__
@@ -665,11 +693,13 @@ int pubDateToUnix (char const * const pubDate) {
 		time_unix = timegm(t);
 #endif
 	}
-	
+
+#ifdef LOCALEPATH
 	if (oldlocale) {
 		setlocale(LC_TIME, oldlocale);
 		free (oldlocale);
 	}
+#endif
 	
 	free (t);
 	return time_unix;
