@@ -1,14 +1,11 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: dialog.c 1083 2005-06-05 09:56:01Z kiza $
+ * $Id: dialog.c 1177 2008-02-17 09:20:34Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
  *
  * dialog.c
  *
- * Please read the file README.patching before changing any code in this file!
- *
- *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
  * published by the Free Software Foundation.
@@ -48,6 +45,8 @@ extern struct keybindings keybindings;
 extern struct categories *first_category;
 extern struct color color;
  
+extern int cursor_always_visible;
+
 char * UIOneLineEntryField (int x, int y) {
 	char *text;
 
@@ -65,7 +64,8 @@ char * UIOneLineEntryField (int x, int y) {
 	getnstr (text, 511);
 
 	noecho();
-	curs_set(0);
+	if (!cursor_always_visible)
+		curs_set(0);
 	attroff (WA_REVERSE);
 
 	/* This memory needs to be freed in the calling function! */
@@ -491,7 +491,7 @@ void UIDisplayFeedHelp (void) {
 	mvprintw (centery-1, centerx-offsetstr, _("Open homepage"));
 	mvprintw (centery,   centerx-offsetstr, _("Open link"));
 	mvprintw (centery+1, centerx-offsetstr, _("Mark all read"));
-	mvprintw (centery+2, centerx-offsetstr, _("Mark item unread"));
+	mvprintw (centery+2, centerx-offsetstr, _("Toggle item read status"));
 	mvprintw (centery+3, centerx-offsetstr, _("Show feed info..."));
 	mvaddstr (centery+4, centerx-offsetstr, _("Type Ahead Find"));
 	mvprintw (centery+5, centerx-offsetstr, _("Return to main menu"));
