@@ -1,14 +1,11 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: interface.c 1083 2005-06-05 09:56:01Z kiza $
+ * $Id: interface.c 1177 2008-02-17 09:20:34Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
  *
  * interface.c
  *
- * Please read the file README.patching before changing any code in this file!
- *
- *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
  * published by the Free Software Foundation.
@@ -53,6 +50,7 @@ extern struct keybindings keybindings;
 extern struct color color;
 extern int use_colors;
 extern struct categories *first_category;
+extern int cursor_always_visible;
 
 struct feed *first_bak = NULL;	/* Backup first pointer for filter mode.
 								   Needs to be global so it can be used in the signal handler.
@@ -785,7 +783,9 @@ int UIDisplayFeed (struct feed * current_feed) {
 				}
 			}
 			if (uiinput == keybindings.markunread) {
-				highlighted->data->readstatus = 0;
+				/* highlighted->data->readstatus = 0; */
+				/* Works as toggle function now. */
+				(highlighted->data->readstatus == 0) ? (highlighted->data->readstatus = 1) : (highlighted->data->readstatus = 0);
 				reloaded = 1;
 			}
 			if (uiinput == keybindings.about)
@@ -803,7 +803,8 @@ int UIDisplayFeed (struct feed * current_feed) {
 			if (typeahead) {
 				free (search);
 				typeahead = 0;
-				curs_set(0);
+				if (!cursor_always_visible)
+					curs_set(0);
 				skip = 0;
 			}
 			/* Check if we have no items at all!
@@ -842,12 +843,13 @@ int UIDisplayFeed (struct feed * current_feed) {
 		}
 		
 		/* TAB key is decimal 9. */
-		if (uiinput == 9) {
+		if (uiinput == 9 || uiinput == keybindings.typeahead) {
 			if (typeahead) {
 				if (searchlen == 0) {
 					typeahead = 0;
 					/* Typeahead now off. */
-					curs_set(0);
+					if (!cursor_always_visible)
+						curs_set(0);
 					free (search);
 					skip = 0;
 					highlighted = savestart;
@@ -1657,7 +1659,7 @@ void UIMainInterface (void) {
 		}
 		
 		/* TAB key is decimal 9. */
-		if (uiinput == 9) {
+		if (uiinput == 9 || uiinput == keybindings.typeahead) {
 			if (typeahead) {
 				if (searchlen == 0) {
 					typeahead = 0;
