@@ -1,14 +1,11 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: net-support.c 500 2004-12-08 14:02:44Z kiza $
+ * $Id: net-support.c 1159 2005-09-13 19:51:13Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
  *
  * net-support.c
  *
- * Please read the file README.patching before changing any code in this file!
- *
- *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
  * published by the Free Software Foundation.
@@ -34,7 +31,7 @@
 
 #include "digcalc.h"
 
-char * ConstructBasicAuth (char * username, char * password) {
+char * ConstructBasicAuth (const char * username, const char * password) {
 	int len;
 	char * authinfo;
 	char * authstring;
@@ -88,10 +85,10 @@ char * GetRandomBytes (void) {
 }
 
 char * ConstructDigestAuth (char * username, char * password, char * url, char * authdata) {
-	char * authinfo;			/* Authorization header as sent to the server. */
+	char * authinfo;		/* Authorization header as sent to the server. */
 	char * token;
 	int len;
-	char * realm = NULL;		/* Variables for the overcomplicated and annoying HTTP digest algo. */
+	char * realm = NULL;	/* Variables for the overcomplicated and annoying HTTP digest algo. */
 	char * qop = NULL;
 	char * nonce = NULL;
 	char * opaque = NULL;
@@ -171,7 +168,7 @@ Authorization: Digest username="(username)", realm="(realm)",
 nonce="(nonce)", uri="(url)", algorithm=MD5, response="(Response)",
 qop=(auth), nc=(szNonceCount), cnonce="deadbeef"
 */
-int NetSupportAuth (struct feed * cur_ptr, char * authdata, char * url, char * netbuf) {
+int NetSupportAuth (struct feed * cur_ptr, const char * authdata, char * url, const char * netbuf) {
 	char * header;
 	char * tmpstr;
 	char * freeme;
@@ -257,7 +254,7 @@ int NetSupportAuth (struct feed * cur_ptr, char * authdata, char * url, char * n
 int checkValidHTTPHeader (const unsigned char * header, int size) {
 	int i, len;
 	
-	len = strlen(header);
+	len = strlen((char *)header);
 	if (len > size)
 		return -1;
 	
@@ -272,10 +269,10 @@ int checkValidHTTPHeader (const unsigned char * header, int size) {
 int checkValidHTTPURL (const unsigned char * url) {
 	int i, len;
 	
-	if (strncasecmp(url, "http://", 7) != 0)
+	if (strncasecmp((char *)url, "http://", 7) != 0)
 		return -1;
 	
-	len = strlen(url);
+	len = strlen((char *)url);
 		
 	for (i = 0; i < len; i++) {
 		if ((url[i] < 32) || (url[i] > 126))
