@@ -1,14 +1,11 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: netio.c 1058 2005-04-27 18:04:47Z kiza $
+ * $Id: netio.c 1173 2006-10-14 21:41:42Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
  *
  * netio.c
  *
- * Please read the file README.patching before changing any code in this file!
- *
- *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
  * published by the Free Software Foundation.
@@ -659,6 +656,7 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 			   does not work with binary data and fails valgrind tests.
 			   Disabled as of 1.5.7. */
 #ifdef USE_UNSUPPORTED_AND_BROKEN_CODE
+#warning ===The function decodedechunked() is not safe for binary data. Since you specifically requested it to be compiled in you probably know better what you are doing than me. Do not report bugs for this code.===
 			if (strstr (netbuf, "chunked") != NULL)
 				chunked = 1;
 #else
