@@ -1,14 +1,11 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: setup.c 1083 2005-06-05 09:56:01Z kiza $
+ * $Id: setup.c 1159 2005-09-13 19:51:13Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
  *
  * setup.c
  *
- * Please read the file README.patching before changing any code in this file!
- *
- *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
  * published by the Free Software Foundation.
@@ -57,8 +54,8 @@ unsigned short proxyport = 0;		/* Port on proxyserver to use. */
 int use_colors = 1;					/* Default to enabled. */
 
 /* Load browser command from ~./snownews/browser. */
-void SetupBrowser (char * file) {
-	char filebuf[4096];
+void SetupBrowser (const char * file) {
+	char filebuf[256];
 	FILE *configfile;
 
 	configfile = fopen (file, "r");
@@ -146,8 +143,8 @@ void SetupUserAgent (void) {
 }
 
 /* Define global keybindings and load user customized bindings. */
-void SetupKeybindings (char * file) {
-	char filebuf[4096];
+void SetupKeybindings (const char * file) {
+	char filebuf[128];
 	char *freeme, *tmpbuf;
 	FILE *configfile;
 
@@ -188,6 +185,7 @@ void SetupKeybindings (char * file) {
 	keybindings.andxor = 'X';
 	keybindings.enter = 'l';
 	keybindings.newheadlines = 'H';
+	keybindings.typeahead = '/';
 	
 	configfile = fopen (file, "r");
 
@@ -274,6 +272,8 @@ void SetupKeybindings (char * file) {
 				keybindings.enter = tmpbuf[0];
 			else if (strcmp (freeme, "show new headlines") == 0)
 				keybindings.newheadlines = tmpbuf[0];
+			else if (strcmp (freeme, "type ahead find") == 0)
+				keybindings.typeahead = tmpbuf[0];
 			
 			free (freeme);
 		}
@@ -325,12 +325,13 @@ void SetupKeybindings (char * file) {
 	fprintf (configfile, "show new headlines:%c\n", keybindings.newheadlines);
 	fprintf (configfile, "help menu:%c\n", keybindings.help);
 	fprintf (configfile, "about:%c\n", keybindings.about);
+	fprintf (configfile, "type ahead find:%c\n", keybindings.typeahead);
 	fclose (configfile);
 }
 
 /* Set up colors and load user customized colors. */
-void SetupColors (char * file) {
-	char filebuf[4096];
+void SetupColors (const char * file) {
+	char filebuf[128];
 	char *freeme, *tmpbuf;
 	FILE *configfile;
 
@@ -457,8 +458,8 @@ void SetupColors (char * file) {
 }
 
 /* Load user customized entity conversion table. */
-void SetupEntities (char * file) {
-	char filebuf[4096];
+void SetupEntities (const char * file) {
+	char filebuf[128];
 	char *freeme, *tmpbuf, *tmppos;
 	FILE *configfile;
 	struct entity *entity;
@@ -537,7 +538,7 @@ void SetupEntities (char * file) {
    Returns number of feeds successfully loaded. */
 int Config (void) {
 	char file[512];					/* File locations. */
-	char filebuf[4096];
+	char filebuf[2048];
 	char *freeme, *tmpbuf, *tmppos, *tmpstr;
 	char *categories = NULL;		/* Holds comma seperated category string. */
 	FILE *configfile;
