@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: xmlparse.c 449 2004-11-29 18:59:57Z kiza $
+ * $Id: xmlparse.c 1146 2005-09-10 10:05:21Z kiza $
  * 
  * Copyright 2003-2004 Rene Puls <rpuls@gmx.net> and
  *                     Oliver Feiler <kiza@kcore.de>
@@ -10,9 +10,6 @@
  *
  * xmlparse.c
  *
- * Please read the file README.patching before changing any code in this file!
- *
- *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
  * published by the Free Software Foundation.
@@ -28,7 +25,7 @@
  *
  */
  
-
+#include <stdlib.h>
 #include <string.h>
 
 #include "config.h"
@@ -39,8 +36,8 @@ int saverestore;
 struct newsitem *copy;
 struct newsitem *firstcopy;
 
-static xmlChar const * const dcNs = "http://purl.org/dc/elements/1.1/";
-static xmlChar const * const snowNs = "http://snownews.kcore.de/ns/1.0/";
+static xmlChar const * const dcNs = (unsigned char *)"http://purl.org/dc/elements/1.1/";
+static xmlChar const * const snowNs = (unsigned char *)"http://snownews.kcore.de/ns/1.0/";
 
 /* Wird whrend des Parsens aufgerufen, falls wir auf ein <channel> Element
    treffen. Die Funktion gibt ein neues Struct fr den Newsfeed zurck. */
@@ -81,8 +78,8 @@ void parse_rdf10_channel(struct feed * feed, xmlDocPtr doc, xmlNodePtr node) {
 	for (cur = node; cur != NULL; cur = cur->next) {
 		if (cur->type != XML_ELEMENT_NODE)
 			continue;
-		if (xmlStrcmp(cur->name, "title") == 0) {
-			feed->title = xmlNodeListGetString(doc, cur->children, 1);
+		if (xmlStrcmp(cur->name, (unsigned char *)"title") == 0) {
+			feed->title = (char *)xmlNodeListGetString(doc, cur->children, 1);
 			CleanupString (feed->title, 1);
 			/* Remove trailing newline */
 			if (feed->title != NULL) {
@@ -92,8 +89,8 @@ void parse_rdf10_channel(struct feed * feed, xmlDocPtr doc, xmlNodePtr node) {
 				}
 			}
 		}
-		else if (xmlStrcmp(cur->name, "link") == 0) {
-			feed->link = xmlNodeListGetString(doc, cur->children, 1);
+		else if (xmlStrcmp(cur->name, (unsigned char *)"link") == 0) {
+			feed->link = (char *)xmlNodeListGetString(doc, cur->children, 1);
 			/* Remove trailing newline */
 			if (feed->link != NULL) {
 				if (strlen(feed->link) > 1) {
@@ -102,8 +99,8 @@ void parse_rdf10_channel(struct feed * feed, xmlDocPtr doc, xmlNodePtr node) {
 				}
 			}
 		}
-		else if (xmlStrcmp(cur->name, "description") == 0) {
-			feed->description = xmlNodeListGetString(doc, cur->children, 1);
+		else if (xmlStrcmp(cur->name, (unsigned char *)"description") == 0) {
+			feed->description = (char *)xmlNodeListGetString(doc, cur->children, 1);
 			CleanupString (feed->description, 0);
 		}
 	}
@@ -147,8 +144,8 @@ void parse_rdf20_channel(struct feed * feed, xmlDocPtr doc, xmlNodePtr node)
 	for (cur = node; cur != NULL; cur = cur->next) {
 		if (cur->type != XML_ELEMENT_NODE)
 			continue;
-		if (xmlStrcmp(cur->name, "title") == 0) {
-			feed->title = xmlNodeListGetString(doc, cur->children, 1);
+		if (xmlStrcmp(cur->name, (unsigned char *)"title") == 0) {
+			feed->title = (char *)xmlNodeListGetString(doc, cur->children, 1);
 			CleanupString (feed->title, 1);
 			/* Remove trailing newline */
 			if (feed->title != NULL) {
@@ -158,8 +155,8 @@ void parse_rdf20_channel(struct feed * feed, xmlDocPtr doc, xmlNodePtr node)
 				}
 			}
 		}
-		else if (xmlStrcmp(cur->name, "link") == 0) {
-			feed->link = xmlNodeListGetString(doc, cur->children, 1);
+		else if (xmlStrcmp(cur->name, (unsigned char *)"link") == 0) {
+			feed->link = (char *)xmlNodeListGetString(doc, cur->children, 1);
 			/* Remove trailing newline */
 			if (feed->link != NULL) {
 				if (strlen(feed->link) > 1) {
@@ -168,10 +165,10 @@ void parse_rdf20_channel(struct feed * feed, xmlDocPtr doc, xmlNodePtr node)
 				}
 			}
 		}
-		else if (xmlStrcmp(cur->name, "description") == 0) {
-			feed->description = xmlNodeListGetString(doc, cur->children, 1);
+		else if (xmlStrcmp(cur->name, (unsigned char *)"description") == 0) {
+			feed->description = (char *)xmlNodeListGetString(doc, cur->children, 1);
 			CleanupString (feed->description, 0);
-		} else if (xmlStrcmp(cur->name, "item") == 0) {
+		} else if (xmlStrcmp(cur->name, (unsigned char *)"item") == 0) {
 			parse_rdf10_item(feed, doc, cur->children);
 		}
 	}
@@ -211,8 +208,8 @@ void parse_rdf10_item(struct feed *feed, xmlDocPtr doc, xmlNodePtr node)
 			continue;
 /* Basic RSS */
 /* Title */
-		if (xmlStrcmp(cur->name, "title") == 0) {
-			item->data->title = xmlNodeListGetString(doc, cur->children, 1);
+		if (xmlStrcmp(cur->name, (unsigned char *)"title") == 0) {
+			item->data->title = (char *)xmlNodeListGetString(doc, cur->children, 1);
 			CleanupString (item->data->title, 1);
 			/* Remove trailing newline */
 			if (item->data->title != NULL) {
@@ -222,8 +219,8 @@ void parse_rdf10_item(struct feed *feed, xmlDocPtr doc, xmlNodePtr node)
 				}
 			}
 /* link */
-		} else if (xmlStrcmp(cur->name, "link") == 0) {
-			item->data->link = xmlNodeListGetString(doc, cur->children, 1);
+		} else if (xmlStrcmp(cur->name, (unsigned char *)"link") == 0) {
+			item->data->link = (char *)xmlNodeListGetString(doc, cur->children, 1);
 			/* Remove trailing newline */
 			if (item->data->link != NULL) {
 				if (strlen(item->data->link) > 1) {
@@ -232,45 +229,45 @@ void parse_rdf10_item(struct feed *feed, xmlDocPtr doc, xmlNodePtr node)
 				}
 			}
 /* Description */
-		} else if (xmlStrcmp(cur->name, "description") == 0) {
-			item->data->description = xmlNodeListGetString(doc, cur->children, 1);
+		} else if (xmlStrcmp(cur->name, (unsigned char *)"description") == 0) {
+			item->data->description = (char *)xmlNodeListGetString(doc, cur->children, 1);
 			CleanupString (item->data->description, 0);
 /* Userland extensions (No namespace!)*/
 /* guid */
-		} else if (xmlStrcmp(cur->name, "guid") == 0) {
-			guid = xmlNodeListGetString(doc, cur->children, 1);
+		} else if (xmlStrcmp(cur->name, (unsigned char *)"guid") == 0) {
+			guid = (char *)xmlNodeListGetString(doc, cur->children, 1);
 /* pubDate */
-		} else if (xmlStrcmp(cur->name, "pubDate") == 0) {
-			date_str = xmlNodeListGetString(doc, cur->children, 1);
+		} else if (xmlStrcmp(cur->name, (unsigned char *)"pubDate") == 0) {
+			date_str = (char *)xmlNodeListGetString(doc, cur->children, 1);
 			item->data->date = pubDateToUnix(date_str);
 			xmlFree (date_str);
 /* Dublin Core */
 /* dc:date */
 		} else if (cur->ns &&
 		           (xmlStrcmp(cur->ns->href, dcNs) == 0) && 
-		           (xmlStrcmp(cur->name, "date") == 0)) {
-		    date_str = xmlNodeListGetString(doc, cur->children, 1);
+		           (xmlStrcmp(cur->name, (unsigned char *)"date") == 0)) {
+		    date_str = (char *)xmlNodeListGetString(doc, cur->children, 1);
 			item->data->date = ISODateToUnix(date_str);
 			xmlFree (date_str);
 /* Internal usage */
 /* Obsolete/backware compat/migration code */
-		} else if (xmlStrcmp(cur->name, "readstatus") == 0) {
+		} else if (xmlStrcmp(cur->name, (unsigned char *)"readstatus") == 0) {
 			/* Will cause memory leak otherwise, xmlNodeListGetString must be freed. */
 			readstatusstring = xmlNodeListGetString(doc, cur->children, 1);
-			item->data->readstatus = atoi (readstatusstring);
+			item->data->readstatus = atoi ((char *)readstatusstring);
 			xmlFree (readstatusstring);
 /* Using snow namespace */
 		} else if (cur->ns && (xmlStrcmp(cur->ns->href, snowNs) == 0) &&
-		           (xmlStrcmp(cur->name, "readstatus") == 0)) {
+		           (xmlStrcmp(cur->name, (unsigned char *)"readstatus") == 0)) {
 			readstatusstring = xmlNodeListGetString(doc, cur->children, 1);
-			item->data->readstatus = atoi (readstatusstring);
+			item->data->readstatus = atoi ((char *)readstatusstring);
 			xmlFree (readstatusstring);
 		} else if (cur->ns && (xmlStrcmp(cur->ns->href, snowNs) == 0) &&
-		           (xmlStrcmp(cur->name, "hash") == 0)) {
-			item->data->hash = xmlNodeListGetString(doc, cur->children, 1);
+		           (xmlStrcmp(cur->name, (unsigned char *)"hash") == 0)) {
+			item->data->hash = (char *)xmlNodeListGetString(doc, cur->children, 1);
 		} else if (cur->ns && (xmlStrcmp(cur->ns->href, snowNs) == 0) &&
-		           (xmlStrcmp(cur->name, "date") == 0)) {
-			date_str = xmlNodeListGetString(doc, cur->children, 1);
+		           (xmlStrcmp(cur->name, (unsigned char *)"date") == 0)) {
+			date_str = (char *)xmlNodeListGetString(doc, cur->children, 1);
 			item->data->date = strtoll(date_str, NULL, 10);
 			xmlFree (date_str);
 		}
@@ -375,7 +372,7 @@ int DeXML (struct feed * cur_ptr) {
 	}
 	
 	/* berprfen, ob das Element auch wirklich <RDF> heit */
-	if (xmlStrcmp(cur->name, "RDF") == 0) {
+	if (xmlStrcmp(cur->name, (unsigned char *)"RDF") == 0) {
 	
 		/* Jetzt gehen wir alle Elemente im Dokument durch. Diese Schleife
 		   selbst luft jedoch nur durch die Elemente auf hchster Ebene
@@ -385,20 +382,20 @@ int DeXML (struct feed * cur_ptr) {
 		for (cur = cur->children; cur != NULL; cur = cur->next) {
 			if (cur->type != XML_ELEMENT_NODE)
 				continue;
-			if (xmlStrcmp(cur->name, "channel") == 0)
+			if (xmlStrcmp(cur->name, (unsigned char *)"channel") == 0)
 				parse_rdf10_channel(cur_ptr, doc, cur->children);
-			if (xmlStrcmp(cur->name, "item") == 0)
+			if (xmlStrcmp(cur->name, (unsigned char *)"item") == 0)
 				parse_rdf10_item(cur_ptr, doc, cur->children);
 			/* Last-Modified is only used when reading from internal feeds (disk cache). */
 			if (cur->ns && (xmlStrcmp(cur->ns->href, snowNs) == 0) &&
-				(xmlStrcmp(cur->name, "lastmodified") == 0))
-				cur_ptr->lastmodified = xmlNodeListGetString(doc, cur->children, 1);
+				(xmlStrcmp(cur->name, (unsigned char *)"lastmodified") == 0))
+				cur_ptr->lastmodified = (char *)xmlNodeListGetString(doc, cur->children, 1);
 		}
-	} else if (xmlStrcmp(cur->name, "rss") == 0) {
+	} else if (xmlStrcmp(cur->name, (unsigned char *)"rss") == 0) {
 		for (cur = cur->children; cur != NULL; cur = cur->next) {
 			if (cur->type != XML_ELEMENT_NODE)
 				continue;
-			if (xmlStrcmp(cur->name, "channel") == 0)
+			if (xmlStrcmp(cur->name, (unsigned char *)"channel") == 0)
 				parse_rdf20_channel(cur_ptr, doc, cur->children);
 		}
 	} else {
